mario\_addons package
=====================

Subpackages
-----------

.. toctree::

   mario_addons.plugins

Module contents
---------------

.. automodule:: mario_addons
   :members:
   :undoc-members:
   :show-inheritance:
